@@ -1,5 +1,5 @@
 PMplot <- function(pmatrix, level=0.05, mtitle=NULL, xylabel=NULL, margin=5, legendx=0.73, newwd=TRUE){
-
+  
   if (is.matrix(pmatrix)) {
     nr <- nrow(pmatrix)
     pmatrix[upper.tri(pmatrix, diag=TRUE)] <- NA
@@ -22,12 +22,13 @@ PMplot <- function(pmatrix, level=0.05, mtitle=NULL, xylabel=NULL, margin=5, leg
     if (level == 0.05) {
       pltm <- matrix(as.numeric(cut(as.numeric(pltmm), c(-0.1, 0.01, 0.05, 0.1, 1))), nrow=nr)
       pltmm <- matrix(as.numeric(droplevels(cut(as.numeric(pltmm), c(-0.1, 0.01, 0.05, 0.1, 1)))), nrow=nr)
-    }else  pltm <- matrix(as.numeric(cut(as.numeric(pltmm), c(-0.1, level, 1))), nrow=nr)
-
+    }else  pltmm <- pltm <- matrix(as.numeric(cut(as.numeric(pltmm), c(-0.1, level, 1))), nrow=nr)
+    
     if (level == 0.05) pcolr <- c("#0D0DFF", "#5D5DFF", "#A1A1FF", "#E4E4FF") else pcolr <-  c("#0D0DFF", "#A1A1FF")
     colr <- pcolr[sort(unique(na.omit(as.numeric(pltm))))]
     max.len <- max(nchar(rnpltm))/6
     mar <- rep(margin, 2) #c(8, 8)
+    
     op <- par(mar = c(mar[1] + max.len, mar[1] + max.len, 4, 4))
     zlim <- range(pltmm, na.rm=TRUE)
     image(pltmm, col = colr, axes = FALSE, main = mtitle, zlim = zlim)
@@ -42,17 +43,17 @@ PMplot <- function(pmatrix, level=0.05, mtitle=NULL, xylabel=NULL, margin=5, leg
     }
     abline(h = tk[-1], v = tk[-1], col = "white")
     box()
-
+    
     if (level == 0.05) {
       legen.lab <- c(expression(p > 0.1), expression("0.05 <  p " <=
-        0.1), expression("0.01 < p " <= 0.05), expression(p <=
-        0.01))[rev(5-sort(unique(na.omit(as.numeric(pltm)))))]
+                                                       0.1), expression("0.01 < p " <= 0.05), expression(p <=
+                                                                                                           0.01))[rev(5-sort(unique(na.omit(as.numeric(pltm)))))]
       legend(legendx, 0.99, legen.lab, pch = rep(15, length(colr)),
-        col = rev(colr), pt.cex = 1.5, cex = 0.9)
+             col = rev(colr), pt.cex = 1.5, cex = 0.9)
     } else{
-      legend(legendx, 0.99, title = paste("At", level,
-      "level"), c("insignificant", "significant")[3-sort(unique(na.omit(as.numeric(pltm))))],
-      pch = rep(15, length(colr)), col = rev(colr), pt.cex = 1.5, cex = 0.9)
+      legend(legendx, 0.99, title = paste("At", round(level, 4),
+                                          "level"), c("significant", "insignificant")[3-sort(unique(na.omit(as.numeric(pltm))))],
+             pch = rep(15, length(colr)), col = rev(colr), pt.cex = 1.5, cex = 0.9)
     }
     par(op)
   }# end of if(nr <= 3)
