@@ -39,7 +39,7 @@ contrastmeans <- function(model, modelterm, ctrmatrix, ctrnames=NULL, adj="none"
 			if (length(vars) > 2) cat("\n", "Denominator degree of freedom for", 
 			  sQuote(modelterm), "and its marginal terms vary between", sQuote(Df), "and", 
 			  sQuote(mDf), ".\n","Probabilities will be calculated using", sQuote(Df), "Df.",  "\n")
-		  }else if (class(model)[1] == "lmerMod") {
+		  }else if (inherits(model, "merMod")) {
 		    vars <- unlist(strsplit(modelterm, "\\:"))
 			termlabel <- attr(terms(model),"term.labels")
 			for (i in vars) termlabel <- termlabel[grep(i, termlabel)]
